/**
 * Retrieves the translation of text.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-i18n/
 */
import { __ } from '@wordpress/i18n';

/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-block-editor/#useblockprops
 */
import { useBlockProps, InspectorControls } from '@wordpress/block-editor';
import {
	Panel,
	PanelBody,
	SelectControl,
	TextControl,
} from '@wordpress/components';
import { useState, useEffect } from '@wordpress/element';

/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * Those files can contain any CSS code that gets applied to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */
import './editor.scss';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-edit-save/#edit
 *
 * @param {{
 * 	attributes: {
 * 		height: string,
 * 		width: string
 * 	},
 * 	setAttributes: Function
 * }} props Props.
 * @return {Element} Element to render.
 */
export default function Edit( { attributes, setAttributes } ) {
	const [ onlinemapOptions, onlinemapSetOptions ] = useState( [] );

	useEffect( () => {
		const apiFetchHandler = window.wp?.apiFetch || window.wp?.apiRequest;
		if ( apiFetchHandler ) {
			const path = `/locrmaps/onlinemaps/all`;
			apiFetchHandler( { path } ).then( ( response ) => {
				const onlinemapsOptions = [
					{ label: '--- Select an ONLINEmap ---', value: '' },
				];
				if ( response.onlinemaps instanceof Array ) {
					for ( const onlinemap of response.onlinemaps ) {
						if ( onlinemap.id && onlinemap.name ) {
							onlinemapsOptions.push( {
								label: onlinemap.name,
								value: onlinemap.id,
							} );
						}
					}
				}
				onlinemapSetOptions( onlinemapsOptions );
			} );
		}
	}, [] );

	const { width, height, onlinemap } = attributes;

	return (
		<>
			<InspectorControls>
				<Panel>
					<PanelBody title={ __( 'General' ) }>
						<SelectControl
							label={ __( 'ONLINEmaps' ) }
							value={ onlinemap }
							options={ onlinemapOptions }
							onChange={ ( value ) =>
								setAttributes( { onlinemap: value } )
							}
						/>
						<TextControl
							label={ __( `Width` ) + ' (CSS)' }
							value={ width }
							placeholder="100%, 500px"
							onChange={ ( value ) =>
								setAttributes( { width: value } )
							}
						/>
						<TextControl
							label={ __( 'Height' ) + ' (CSS)' }
							value={ height }
							placeholder="100%, 500px"
							onChange={ ( value ) =>
								setAttributes( { height: value } )
							}
						/>
					</PanelBody>
				</Panel>
			</InspectorControls>
			<p { ...useBlockProps() }>
				<div className="image-block" style={ { textAlign: 'center' } }>
					<img
						src={ `${ window.location.origin }/wp-content/plugins/locrmaps/src/public/png/locrmaps_container_screenshot.png` }
						alt="locrMAPS map placeholder"
					/>
				</div>
			</p>
		</>
	);
}
